==> vdr-plugin-screenshot_0.0.7.orig.tar.gz: screenshot-0.0.7/i18n.c <==
/*
 * i18n.c: Internationalization
 *
 * See the README file for copyright information and how to reach the author.
 *
 */

#include "i18n.h"

const tI18nPhrase Phrases[] = {
  { "Takes screenshots",// English
    "erstellt Bildschirmfotos",// Deutsch
    "",// Slovenski
    "Scatta foto dello schermo",// Italiano
    "",// Nederlands
    "",// Portugus
    "",// Franais
    "",// Norsk
    "Kuvakaappaari",// suomi
    "",// Polski
    "",// Espaol
    "",// 
    "",// Svenska
    "",// Romaneste
    "",// Magyar
    "",// Catal
#if VDRVERSNUM >= 10300
    "" // 
#endif
  },
  { "Screenshot",
    "Bildschirmfoto",
    "",// TODO
    "Stampa schermo",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuvakaappaus",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Image Directory",
    "Bilderverzeichnis",
    "",// TODO
    "Elenco immagini",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Tallennushakemisto",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Image Quality (1-100)",
    "Bildqualitt (1-100)",
    "",// TODO
    "Qualit immagine",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuvanlaatu (0-100)",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Image width (Pixel)",
    "Bildbreite (Pixel)",
    "",// TODO
    "",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Image height (Pixel)",
    "Bildhhe (Pixel)",
    "",// TODO
    "",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Image Quality (1-100)",
    "Bildqualitt (1-100)",
    "",// TODO
    "Qualit immagine",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuvanlaatu (0-100)",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Fileformat",
    "Bildformat",
    "",// TODO
    "Formato immagine",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuvaformaatti",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "OK - Images saved.",
    "OK - Bilder gespeichert.",
    "",// TODO
    "OK",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuva otettu.",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "OK - Image saved.",
    "OK - Bild gespeichert.",
    "",// TODO
    "OK",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuva otettu.",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Error",
    "Fehler",
    "",// TODO
    "Errore",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuvan ottamien eponnistui!",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "No. of pictures to take",
    "Anzahl der aufzunehmenden Bilder",
    "",// TODO
    "Numero foto da scattare",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kerralla otettavien kuvien lukumr",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Hide mainmenu entry",
    "Menueintrag ausblenden",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "User key to use",
    "Benutze benutzerdefinierte Taste Nr.",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Hide OSD",
    "OSD ausblenden",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { NULL }
  };

==> vdr-plugin-screenshot_0.0.11.orig.tar.gz: screenshot-0.0.11/i18n.c <==
/*
 * i18n.c: Internationalization
 *
 * See the README file for copyright information and how to reach the author.
 *
 */

#include "i18n.h"

const tI18nPhrase Phrases[] = {
  { "Takes screenshots",// English
    "erstellt Bildschirmfotos",// Deutsch
    "",// Slovenski
    "Scatta foto dello schermo",// Italiano
    "",// Nederlands
    "",// Portugus
    "",// Franais
    "",// Norsk
    "Kuvakaappaari",// suomi
    "",// Polski
    "Ver Imagenes",// Espaol
    "",// 
    "",// Svenska
    "",// Romaneste
    "",// Magyar
    "Veure Imatges",// Catal
#if VDRVERSNUM >= 10300
    "" // 
#endif
  },
  { "Screenshot",
    "Bildschirmfoto",
    "",// TODO
    "Stampa schermo",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuvakaappaus",
    "",// TODO
    "Capturas",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Captures",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Image directory",
    "Bilderverzeichnis",
    "",// TODO
    "Elenco immagini",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Tallennushakemisto",
    "",// TODO
    "Directorio de imagenes",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Directori d'imatges",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Image quality (1-100)",
    "Bildqualitt (1-100)",
    "",// TODO
    "Qualit immagine",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuvanlaatu (0-100)",
    "",// TODO
    "Calidad de imagen (1-100)",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Qualitat d'imatge (1-100)",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Image width (Pixel)",
    "Bildbreite (Pixel)",
    "",// TODO
    "",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
    "",// TODO
    "Ancho imagen (pixels)",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Amplada imatge (pixels)",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Image height (Pixel)",
    "Bildhhe (Pixel)",
    "",// TODO
    "",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",
    "",// TODO
    "Alto imagen",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Alada imatge",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Fileformat",
    "Bildformat",
    "",// TODO
    "Formato immagine",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuvaformaatti",
    "",// TODO
    "Formato imagen",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Format imatge",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "OK - Images saved.",
    "OK - Bilder gespeichert.",
    "",// TODO
    "OK",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuva otettu.",
    "",// TODO
    "Ok - Imagenes guardad",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "OK - Imatges salvades",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "OK - Image saved.",
    "OK - Bild gespeichert.",
    "",// TODO
    "OK",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuva otettu.",
    "",// TODO
    "Ok - Imagen guardada",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Ok - Imatge salvada",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Error",
    "Fehler",
    "",// TODO
    "Errore",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kuvan ottamien eponnistui!",
    "",// TODO
    "Error",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Error",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "No. of pictures to take",
    "Anzahl der aufzunehmenden Bilder",
    "",// TODO
    "Numero foto da scattare",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kerralla otettavien kuvien lukumr",
    "",// TODO
    "N de fotos a coger",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Nombre d'imatges per afagar",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Hide mainmenu entry",
    "Menueintrag ausblenden",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Piilota valinta pvalikosta",
    "",// TODO
    "Ocultar entrada en el menu",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Ocultar entrada al menu",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "User key to use",
    "Benutze benutzerdefinierte Taste Nr.",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Kyt nppint [User]",
    "",// TODO
    "Asignar tecla de usuario",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Tecla usuari per utilitzar",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Hide OSD",
    "OSD ausblenden",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Piilota kuvaruutunytt",
    "",// TODO
    "Ocultar OSD",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "Ocultar OSD",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Filename",
    "Dateiname",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Go",
    "Los",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Show Date",
    "Datum einblenden",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Delayed shooting active.",
    "Verzgertes Auslsen aktiviert.",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { "Enable delayed shooting",
    "Verzgertes Auslsen aktivieren",
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
    "",// TODO
#if VDRVERSNUM >= 10300
    "" // TODO
#endif
  },
  { NULL }
  };
